"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fastify_plugin_1 = require("fastify-plugin");
const graphql_1 = require("graphql");
const postgraphile_1 = require("postgraphile");
const create_pool_1 = require("./create-pool");
const schema_1 = require("./schema");
const QueryPerformer_1 = require("./QueryPerformer");
module.exports = fastify_plugin_1.default(async function (fastify, opts) {
    const pool = create_pool_1.createPool(opts.pool);
    const schema = await schema_1.createSchema(postgraphile_1.createPostGraphileSchema, pool, opts.schemas);
    const queryPerformer = new QueryPerformer_1.QueryPerformer(schema, graphql_1.graphql, postgraphile_1.withPostGraphileContext, pool, opts.contextOptions);
    fastify.decorateReply('graphql', queryPerformer.perform.bind(queryPerformer));
}, { fastify: '3.x' });
